@@ -106,7 +106,7 @@ public class GDE {
 	private static boolean									isWithUi													= false;
 
 	// ****** begin global constants section *******
-	public static final String							VERSION														= "Version 3.9.0"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
+	public static final String							VERSION														= "Version 3.9.1"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
 	public static final int									VERSION_NUMBER										= GDE.VERSION.contains("beta") 
 															? Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY)) - 1
 															: Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY));
@@ -521,7 +521,8 @@ public class GDE {
 				}
 			}
 
-			Settings.getInstance().checkUpdateDeviceProperties(Settings.getDevicesPath());
+			//special handling replacing device XML without schema update
+			//Settings.getInstance().checkUpdateDeviceProperties(Settings.getDevicesPath());
 
 			// list system properties
 			StringBuilder sb = new StringBuilder().append("Environment : \n"); //$NON-NLS-1$
@@ -707,7 +708,7 @@ public class GDE {
 		GC gc = new GC(image);
 		gc.drawImage(image, 0, 0);
 		gc.dispose();
-		final Shell splashShell = new Shell(GDE.shell, SWT.ON_TOP | SWT.BORDER);
+		final Shell splashShell = new Shell(GDE.shell, SWT.ON_TOP | SWT.BORDER | SWT.MODELESS);
 		final ProgressBar bar = new ProgressBar(splashShell, SWT.NONE);
 		bar.setMaximum(100);
 		final Label label = new Label(splashShell, SWT.NONE);
@@ -773,11 +774,11 @@ public class GDE {
 														@Override
 														public int getProgressPercentage() { return 100; }
 														@Override
-														public void setProgress(int percentage) {}
+														public void setProgress(int percentage) {/* nothing to do */}
 														@Override
-														public void setStatusMessage(String message) {}
+														public void setStatusMessage(String message) { /* nothing to do */}
 														@Override
-														public void setStatusMessage(String message, int swtColor) {}
+														public void setStatusMessage(String message, int swtColor) {/* nothing to do */}
 														};
       //@formatter:on
 		}
