@@ -1,6 +1,21 @@
-/**
- *
- */
+/**************************************************************************************
+  	This file is part of GNU DataExplorer.
+
+    GNU DataExplorer is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    DataExplorer is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
+
+    Copyright (c) 2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Winfried Bruegmann
+****************************************************************************************/
 package gde.device.graupner;
 
 import java.io.DataInputStream;
@@ -592,19 +607,6 @@ public class HoTTlogReader extends HoTTbinReader {
 		HoTTlogReader.recordSetReceiver.addPoints(HoTTlogReader.rcvLogParser.getPoints(), HoTTlogReader.rcvLogParser.getTimeStep_ms());
 	}
 
-	/**
-	 * parse the buffered data from buffer and add points to record set
-	 * @param _buf
-	 * @throws DataInconsitsentException
-	 */
-	protected static void parseAddReceiverRxTxOnly(byte[] _buf) throws DataInconsitsentException {
-		int[] tmpPoints = new int[10];
-		System.arraycopy(HoTTlogReader.rcvLogParser.points, 0, tmpPoints, 0, 10);
-		HoTTlogReader.rcvLogParser.parseTxRxOnly();
-		System.arraycopy(HoTTlogReader.rcvLogParser.getPoints(), 4, tmpPoints, 4, 2); //Rx and Tx values only, keep other data since invalid
-		HoTTlogReader.recordSetReceiver.addPoints(tmpPoints, HoTTlogReader.rcvLogParser.getTimeStep_ms());
-	}
-
 	public static class RcvLogParser extends LogParser {
 		private int																	tmpVoltageRx			= 0;
 		private int																	tmpTemperatureRx	= 0;
